@@ -132,16 +132,16 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
             char* des = MALLOC(des_size+1);
 #if defined(__DARWIN__)
             if(is_all_ascii(src)) {
-                strncpy(des, src, des_size);
+                xstrncpy(des, src, des_size);
             }
             else {
                 /// コンバート ///
                 if(kanji_convert(src, des, des_size, gKanjiCodeFileName, gKanjiCode) < 0) {
-                    strncpy(des, src, des_size);
+                    xstrncpy(des, src, des_size);
                 }
             }
 #else
-            strncpy(des, src, des_size);
+            xstrncpy(des, src, des_size);
 #endif
             vector_add(all_candidate2, STRING_NEW(des));
             FREE(des);
@@ -156,7 +156,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
     }
 
     gCompletionAddSpace = add_space;
-    strncpy(gEditing, editing, kCmdLineMax);
+    xstrncpy(gEditing, editing, kCmdLineMax);
     gEditingLen = strlen(gEditing);
 
     cmdline_completion_clear();
@@ -218,7 +218,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
                         string_insert(str, gCmdLineCursor, tmp);
                         gCmdLineCursor+=utf8_len;
                         gEditingLen+=utf8_len;
-                        strncat(gEditing, tmp, kCmdLineMax);
+                        xstrncat(gEditing, tmp, kCmdLineMax);
                         utf8_size = -1;
                         utf8_len = 0;
                     }
@@ -239,7 +239,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
                         gCmdLineCursor++;
 
                         gEditingLen++;
-                        strncat(gEditing, tmp, kCmdLineMax);
+                        xstrncat(gEditing, tmp, kCmdLineMax);
                     }
                 }
             }
@@ -292,7 +292,7 @@ void cmdline_completion(vector_obj* all_candidate, char* editing, BOOL add_space
 void cmdline_completion_file(char* editing_dir, char* editing_file, char* editing, int editing_position)
 {
     char editing_dir2[kCmdLineMax];
-    strncpy(editing_dir2, editing_dir, kCmdLineMax);
+    xstrncpy(editing_dir2, editing_dir, kCmdLineMax);
 
     /// editing_dirが存在するなら ///
     if(strcmp(editing_dir2, "") != 0) {
@@ -313,10 +313,10 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             
             char* env = getenv(env_name);
             if(env) {
-                strncpy(new_editing_dir, env, kCmdLineMax);
-                strncat(new_editing_dir, p, kCmdLineMax);
+                xstrncpy(new_editing_dir, env, kCmdLineMax);
+                xstrncat(new_editing_dir, p, kCmdLineMax);
 
-                strncpy(editing_dir2, new_editing_dir, PATH_MAX);
+                xstrncpy(editing_dir2, new_editing_dir, PATH_MAX);
             }
         }
 
@@ -327,10 +327,10 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
             char* p = editing_dir2;
             p++;
 
-            strncpy(new_editing_dir, getenv("HOME"), kCmdLineMax);
-            strncat(new_editing_dir, p, kCmdLineMax);
+            xstrncpy(new_editing_dir, getenv("HOME"), kCmdLineMax);
+            xstrncat(new_editing_dir, p, kCmdLineMax);
 
-            strncpy(editing_dir2, new_editing_dir, kCmdLineMax);
+            xstrncpy(editing_dir2, new_editing_dir, kCmdLineMax);
         }
 
         DIR* dir = opendir(editing_dir2);
@@ -348,9 +348,9 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                     snprintf(buf, PATH_MAX, "%s%s", editing_dir2, entry->d_name);
                     stat(buf, &_stat);
 
-                    strncpy(buf, entry->d_name, PATH_MAX);
+                    xstrncpy(buf, entry->d_name, PATH_MAX);
                     if(S_ISDIR(_stat.st_mode)) {
-                        strncat(buf, "/", PATH_MAX);
+                        xstrncat(buf, "/", PATH_MAX);
                     }
 
                     vector_add(files, STRING_NEW(buf));
@@ -398,9 +398,9 @@ void cmdline_completion_file(char* editing_dir, char* editing_file, char* editin
                         snprintf(buf, PATH_MAX, "./%s", entry->d_name);
                         stat(buf, &_stat);
 
-                        strncpy(buf, entry->d_name, PATH_MAX);
+                        xstrncpy(buf, entry->d_name, PATH_MAX);
                         if(S_ISDIR(_stat.st_mode)) {
-                            strncat(buf, "/", PATH_MAX);
+                            xstrncat(buf, "/", PATH_MAX);
                         }
                         vector_add(files, STRING_NEW(buf));
                     }
@@ -536,8 +536,8 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
     *e = 0;
     *editing_position = 0;
-    strncpy(cmdname, "", kCmdLineMax);
-    strncpy(editing_before, "", kCmdLineMax);
+    xstrncpy(cmdname, "", kCmdLineMax);
+    xstrncpy(editing_before, "", kCmdLineMax);
     *squote = FALSE;
     *dquote = FALSE;
     *last_squote = FALSE;
@@ -572,10 +572,10 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strncpy(editing_before, editing, kCmdLineMax);
+            xstrncpy(editing_before, editing, kCmdLineMax);
 
             if(editing[0] != '%' && editing[0] != '-') {
-                if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
+                if(*editing_position == 0) xstrncpy(cmdname, editing, kCmdLineMax);
                 (*editing_position)++;
             }
 
@@ -589,10 +589,10 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strncpy(editing_before, editing, kCmdLineMax);
+            xstrncpy(editing_before, editing, kCmdLineMax);
 
             if(editing[0] != '%' && editing[0] != '-') {
-                if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
+                if(*editing_position == 0) xstrncpy(cmdname, editing, kCmdLineMax);
                 (*editing_position)++;
             }
 
@@ -606,11 +606,11 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
 
             *e = 0;
             vector_add(*earray, STRING_NEW(editing));
-            strncpy(editing_before, editing, kCmdLineMax);
+            xstrncpy(editing_before, editing, kCmdLineMax);
 
             e = editing;
 
-            strncpy(cmdname, "", kCmdLineMax);
+            xstrncpy(cmdname, "", kCmdLineMax);
             *editing_position = 0;
             int i;
             for(i=0; i<vector_size(*earray); i++) {
@@ -630,7 +630,7 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     vector_add(*earray, STRING_NEW(editing));
     if(editing[0] != '%' && editing[0] != '-')
     {
-        if(*editing_position == 0) strncpy(cmdname, editing, kCmdLineMax);
+        if(*editing_position == 0) xstrncpy(cmdname, editing, kCmdLineMax);
     }
 
     if(strlen(cmdline) >= gCmdLineCursor && cmdline[gCmdLineCursor] == '\'') {
@@ -642,8 +642,8 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     }
 
     /// divide editing into dir part and file part ///
-    strncpy(editing_dir, "", kCmdLineMax);
-    strncpy(editing_file, "", kCmdLineMax);
+    xstrncpy(editing_dir, "", kCmdLineMax);
+    xstrncpy(editing_file, "", kCmdLineMax);
 
     e = editing + strlen(editing);
     while(e >= editing) {
@@ -660,7 +660,7 @@ void cmdline_parse(char* cmdname, char* editing, char* editing_before, char* edi
     }
 
     if(strcmp(editing_dir, "") == 0) {
-        strncpy(editing_file, editing, kCmdLineMax);
+        xstrncpy(editing_file, editing, kCmdLineMax);
     }
 
     int i;
