@@ -198,7 +198,7 @@ void commands_final();
 ///////////////////////////////////////////////////
 // file.c
 ///////////////////////////////////////////////////
-enum eCopyOverride { kNone, kYesAll, kNoAll, kCancel, kSelectNewer };
+enum eCopyOverride { kNone, kYesAll, kNoAll, kCancel, kSelectNewer, kYesAllRemainPermission };
 extern enum eCopyOverride gCopyOverride;
 
 enum eWriteProtected { kWPNone, kWPYesAll, kWPNoAll, kWPCancel };
