@@ -37,18 +37,18 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     
     mmvprintw(y+1, 5, "source");
     char tmp[PATH_MAX];
-    strncpy(tmp, spath, PATH_MAX);
+    xstrncpy(tmp, spath, PATH_MAX);
     if(S_ISDIR(stat_.st_mode)) {
-        strncat(tmp, "/", PATH_MAX);
+        xstrncat(tmp, "/", PATH_MAX);
     }
     else if(S_ISFIFO(stat_.st_mode)) {
-        strncat(tmp, "|", PATH_MAX);
+        xstrncat(tmp, "|", PATH_MAX);
     }
     else if(S_ISSOCK(stat_.st_mode)) {
-        strncat(tmp, "=", PATH_MAX);
+        xstrncat(tmp, "=", PATH_MAX);
     }
     else if(S_ISLNK(stat_.st_mode)) {
-        strncat(tmp, "@", PATH_MAX);
+        xstrncat(tmp, "@", PATH_MAX);
     }
     
     
@@ -66,18 +66,18 @@ void file_copy_override_box(char* spath, struct stat stat_, char* dfile, struct
     
     mmvprintw(y+6, 5, "distination");
     char tmp2[PATH_MAX];
-    strncpy(tmp2, dfile, PATH_MAX);
+    xstrncpy(tmp2, dfile, PATH_MAX);
     if(S_ISDIR(dfstat.st_mode)) {
-        strncat(tmp2, "/", PATH_MAX);
+        xstrncat(tmp2, "/", PATH_MAX);
     }
     else if(S_ISFIFO(dfstat.st_mode)) {
-        strncat(tmp, "|", PATH_MAX);
+        xstrncat(tmp, "|", PATH_MAX);
     }
     else if(S_ISSOCK(dfstat.st_mode)) {
-        strncat(tmp, "=", PATH_MAX);
+        xstrncat(tmp, "=", PATH_MAX);
     }
     else if(S_ISLNK(dfstat.st_mode)) {
-        strncat(tmp, "@", PATH_MAX);
+        xstrncat(tmp, "@", PATH_MAX);
     }
     
     mmvprintw(y+7, 5, "path: %s", tmp2);
@@ -122,7 +122,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     
     /// new file name check ///
     char new_fname[PATH_MAX];
-    strncpy(new_fname, "", PATH_MAX);
+    xstrncpy(new_fname, "", PATH_MAX);
     
     struct stat dstat;
     const int dlen = strlen(dpath);
@@ -137,7 +137,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             while(p != dpath && *p != '/') {
                 p--;
             }
-            strncpy(new_fname, p+1, PATH_MAX);
+            xstrncpy(new_fname, p+1, PATH_MAX);
 
             dpath[p-dpath+1] = 0;
         }
@@ -147,7 +147,7 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
         while(p != dpath && *p != '/') {
             p--;
         }
-        strncpy(new_fname, p+1, PATH_MAX);
+        xstrncpy(new_fname, p+1, PATH_MAX);
 
         dpath[p-dpath+1] = 0;
     }
@@ -155,8 +155,8 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     /// add / ///
     char new_dpath[PATH_MAX];
     if(dpath[strlen(dpath) -1] != '/') {
-        strncpy(new_dpath, dpath, PATH_MAX);
-        strncat(new_dpath, "/", PATH_MAX);
+        xstrncpy(new_dpath, dpath, PATH_MAX);
+        xstrncat(new_dpath, "/", PATH_MAX);
 
         dpath = new_dpath;
     }
@@ -174,8 +174,8 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
     /// illegal argument check ///
     char spath2[PATH_MAX];
 
-    strncpy(spath2, spath, PATH_MAX);
-    strncat(spath2, "/", PATH_MAX);
+    xstrncpy(spath2, spath, PATH_MAX);
+    xstrncat(spath2, "/", PATH_MAX);
         
     if(strstr(dpath, spath2) == dpath) {
         merr_msg("file_copy: destination err(%s)", dpath);
@@ -205,12 +205,12 @@ BOOL file_copy(char* spath, char* dpath, BOOL move, BOOL preserve)
             memcpy(sfname, spath + i + 1, len - i);
 
             /// get destination file name ///
-            strncpy(dfile, dpath, PATH_MAX);
-            strncat(dfile, sfname, PATH_MAX);
+            xstrncpy(dfile, dpath, PATH_MAX);
+            xstrncat(dfile, sfname, PATH_MAX);
         }
         else {
-            strncpy(dfile, dpath, PATH_MAX);
-            strncat(dfile, new_fname, PATH_MAX);
+            xstrncpy(dfile, dpath, PATH_MAX);
+            xstrncat(dfile, new_fname, PATH_MAX);
         }
 
         /// illegal argument check ///
@@ -290,8 +290,8 @@ override_select_str:
                                     goto override_select_str;
                                 }
                                 
-                                strncpy(dfile_tmp, dpath, PATH_MAX);
-                                strncat(dfile_tmp, result, PATH_MAX);
+                                xstrncpy(dfile_tmp, dpath, PATH_MAX);
+                                xstrncat(dfile_tmp, result, PATH_MAX);
                                 
                                 exist_rename_file = access(dfile_tmp, F_OK) == 0;
                                 
@@ -300,7 +300,7 @@ override_select_str:
                                 }
                             } while(exist_rename_file);
                             
-                            strncpy(dfile,dfile_tmp, PATH_MAX);
+                            xstrncpy(dfile,dfile_tmp, PATH_MAX);
                             
                             }
                             break;
@@ -382,14 +382,14 @@ dir_copy:
                     {
                         char spath2[PATH_MAX];
 
-                        strncpy(spath2, spath, PATH_MAX);
-                        strncat(spath2, "/", PATH_MAX);
-                        strncat(spath2, entry->d_name, PATH_MAX);
+                        xstrncpy(spath2, spath, PATH_MAX);
+                        xstrncat(spath2, "/", PATH_MAX);
+                        xstrncat(spath2, entry->d_name, PATH_MAX);
 
                         char dfile2[PATH_MAX];
         
-                        strncpy(dfile2, dfile, PATH_MAX);
-                        strncat(dfile2, "/", PATH_MAX);
+                        xstrncpy(dfile2, dfile, PATH_MAX);
+                        xstrncat(dfile2, "/", PATH_MAX);
         
                         if(!file_copy(spath2, dfile2, move, preserve)) {
                             closedir(dir);
@@ -520,8 +520,8 @@ override_select_str2:
                                 goto override_select_str2;
                             }
                             
-                            strncpy(dfile_tmp, dpath, PATH_MAX);
-                            strncat(dfile_tmp, result, PATH_MAX);
+                            xstrncpy(dfile_tmp, dpath, PATH_MAX);
+                            xstrncat(dfile_tmp, result, PATH_MAX);
                             
                             exist_rename_file = access(dfile_tmp, F_OK) == 0;
                             if(exist_rename_file) {
@@ -529,7 +529,7 @@ override_select_str2:
                             }
                         } while(exist_rename_file);
                         
-                        strncpy(dfile, dfile_tmp, PATH_MAX);
+                        xstrncpy(dfile, dfile_tmp, PATH_MAX);
                         
                         }
                         break;
@@ -1150,9 +1150,9 @@ BOOL file_remove(char* path, BOOL no_ctrl_c, BOOL message)
                     && strcmp(entry->d_name, "..") != 0)
                 {
                     char path2[PATH_MAX];
-                    strncpy(path2, path, PATH_MAX);
-                    strncat(path2, "/", PATH_MAX);
-                    strncat(path2, entry->d_name, PATH_MAX);
+                    xstrncpy(path2, path, PATH_MAX);
+                    xstrncat(path2, "/", PATH_MAX);
+                    xstrncat(path2, entry->d_name, PATH_MAX);
 
                     if(!file_remove(path2, no_ctrl_c, FALSE)) {
                         closedir(dir);
