@@ -56,6 +56,7 @@ void ISearchClear()
 ///////////////////////////////////////////////////
 // 内部定義
 ///////////////////////////////////////////////////
+static void migemo_init();
 
 /// 入力された文字列がインクリメンタルサーチ向きかどうか ///
 static BOOL is_isearch_char(int key)
@@ -87,6 +88,13 @@ static BOOL match_back(int start)
     return FALSE;
 
 #else
+
+    if(gMigemoCache == NULL) {
+        gReg = NULL;
+        migemo_init();
+        gMigemoCache = HASH_NEW(100);
+    }
+
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
@@ -217,6 +225,12 @@ static BOOL match_next(int start)
 
 #else
 
+    if(gMigemoCache == NULL) {
+        gReg = NULL;
+        migemo_init();
+        gMigemoCache = HASH_NEW(100);
+    }
+
     if(string_c_str(gInputFileName)[0] != 0) {
         /// get reg ///
         if(gReg == NULL) {
@@ -408,11 +422,9 @@ void isearch_init()
     gInputFileName = STRING_NEW("");
 
 #if defined(HAVE_MIGEMO_H)
+    gMigemoCache = NULL;
     gReg = NULL;
-    migemo_init();
-    gMigemoCache = HASH_NEW(100);
 #endif
-
 }
 
 ///////////////////////////////////////////////////
@@ -423,18 +435,20 @@ void isearch_final()
     string_delete(gInputFileName);
 
 #if defined(HAVE_MIGEMO_H)
-    onig_end();
-    migemo_close(gMigemo);
-    if(gReg && hash_key(gMigemoCache, gReg) == NULL) onig_free(gReg);
-    gReg = NULL;
-    hash_it* it = hash_loop_begin(gMigemoCache);
-    while(it != NULL) {
-        regex_t* reg  = hash_loop_item(it);
-        onig_free(reg);
+    if(gMigemoCache) {
+        onig_end();
+        migemo_close(gMigemo);
+        if(gReg && hash_key(gMigemoCache, gReg) == NULL) onig_free(gReg);
+        gReg = NULL;
+        hash_it* it = hash_loop_begin(gMigemoCache);
+        while(it != NULL) {
+            regex_t* reg  = hash_loop_item(it);
+            onig_free(reg);
 
-        it = hash_loop_next(it);
+            it = hash_loop_next(it);
+        }
+        hash_delete(gMigemoCache);
     }
-    hash_delete(gMigemoCache);
 #endif
 }
 
@@ -443,6 +457,14 @@ void isearch_final()
 ///////////////////////////////////////////////////
 void isearch_input(int meta, int key)
 {
+#if defined(HAVE_MIGEMO_H)
+    if(gMigemoCache == NULL) {
+        gReg = NULL;
+        migemo_init();
+        gMigemoCache = HASH_NEW(100);
+    }
+#endif
+
     if(key == 8 || key == KEY_BACKSPACE || key == KEY_DC) {
         string_erase(gInputFileName, string_length(gInputFileName)-1, 1);
 #if defined(HAVE_MIGEMO_H)
