@@ -832,7 +832,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.3.6", 1);
+    setenv("VERSION", "4.3.9", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
@@ -1078,8 +1078,8 @@ int main(int argc, char* argv[])
     commands_init();
 
     /// 初期キーバインドと初期フック ///
-    filer_add_keycommand(0, 'q', "*", "quit", "system");
-    filer_add_keycommand(0, 3, "*", "quit", "system"); // CTRL-C
+    filer_add_keycommand("filer", 0, 'q', "*", "quit", "system");
+    filer_add_keycommand("filer", 0, 3, "*", "quit", "system"); // CTRL-C
 
     /// ソケットの初期化 ///
     char soc_name[PATH_MAX];
